pub fn apply_env_vars_to_config(yaml_config: &mut Yaml)Expand description
Apply environment variable overrides with prefix FERRON_ to the provided YAML configuration. Maps directly to the fields in the global section of ferron.yaml.
pub fn apply_env_vars_to_config(yaml_config: &mut Yaml)Apply environment variable overrides with prefix FERRON_ to the provided YAML configuration. Maps directly to the fields in the global section of ferron.yaml.